@@ -20,3 +20,5 @@ SECRET_ACCESS_KEY = 'secret_access_key'
 TENANT = 'tenant_name'
 REGION = 'region_name'
 AUTH_URL = 'auth_url'
+SSH_USER = 'ssh_user'
+SSH_PASS = 'ssh_pass'
